@@ -13,7 +13,7 @@ class Application(tornado.web.Application):
         self.miss = 0
         self.put = 0
         super(Application, self).__init__(
-            [("/(.+)", MultipleRequestHandler), ("/(.+)", KeyRequestHandler), ("/stats", StatsHandler)],
+            [("/", MultipleRequestHandler), ("/stats", StatsHandler), ("/(.+)", KeyRequestHandler)],
             auto_etag=False)
 
     def log_request(self, handler):
